# oeg.infotech.xml

[![Python 2.7](https://img.shields.io/travis/vb64/oeg.infotech.xml.svg?label=Python%202.7&style=plastic)](https://travis-ci.org/vb64/oeg.infotech.xml)
[![Code Climate](https://img.shields.io/codeclimate/maintainability-percentage/vb64/oeg.infotech.xml.svg?label=Code%20Climate&style=plastic)](https://codeclimate.com/github/vb64/oeg.infotech.xml)
[![Coverage Status](https://coveralls.io/repos/github/vb64/oeg.infotech.xml/badge.svg?branch=master)](https://coveralls.io/github/vb64/oeg.infotech.xml?branch=master)

Library for OrgEnergoGaz Infotech xml processing

```
$ git clone git@github.com:vb64/oeg.infotech.xml.git
$ cd oeg.infotech.xml
$ make setup PYTHON_BIN=/usr/bin/python2.7
```
